# Topsis
Topsis-Tarush is a python package to implement Multiple criteria decision making (MCDM) using TOPSIS. It takes data, calculates topsis score and ranks the data according to the score.

## Installation
Run the following command in the terminal to install the package:<br />
```pip install Topsis-Tarush-102083060```

## How to use the Package
You need to provide 4 arguments(csv filename, weights, impacts, output filename) in terminal to run the package.
Sample Case:<br />
```python test.py data.csv "1,2,1,1,2" "+,-,+,-,-" outputfilename.csv```

## License

Copyright(c) 2022 Tarush Srivastava

